==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RelabelConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RelabelConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<A>{
  public RelabelConfigFluentImpl() {
  }
  public RelabelConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance) {
    this.withAction(instance.getAction()); 
    this.withModulus(instance.getModulus()); 
    this.withRegex(instance.getRegex()); 
    this.withReplacement(instance.getReplacement()); 
    this.withSeparator(instance.getSeparator()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withTargetLabel(instance.getTargetLabel()); 
  }
  private java.lang.String action;
  private java.lang.Long modulus;
  private java.lang.String regex;
  private java.lang.String replacement;
  private java.lang.String separator;
  private java.util.List<java.lang.String> sourceLabels = new java.util.ArrayList<java.lang.String>();
  private java.lang.String targetLabel;
  public java.lang.String getAction() {
    return this.action;
  }
  public A withAction(java.lang.String action) {
    this.action=action; return (A) this;
  }
  public java.lang.Boolean hasAction() {
    return this.action != null;
  }
  
  /**
   * Method is deprecated. use withAction instead.
   */
  @java.lang.Deprecated
  public A withNewAction(java.lang.String arg0) {
    return (A)withAction(new String(arg0));
  }
  public java.lang.Long getModulus() {
    return this.modulus;
  }
  public A withModulus(java.lang.Long modulus) {
    this.modulus=modulus; return (A) this;
  }
  public java.lang.Boolean hasModulus() {
    return this.modulus != null;
  }
  public java.lang.String getRegex() {
    return this.regex;
  }
  public A withRegex(java.lang.String regex) {
    this.regex=regex; return (A) this;
  }
  public java.lang.Boolean hasRegex() {
    return this.regex != null;
  }
  
  /**
   * Method is deprecated. use withRegex instead.
   */
  @java.lang.Deprecated
  public A withNewRegex(java.lang.String arg0) {
    return (A)withRegex(new String(arg0));
  }
  public java.lang.String getReplacement() {
    return this.replacement;
  }
  public A withReplacement(java.lang.String replacement) {
    this.replacement=replacement; return (A) this;
  }
  public java.lang.Boolean hasReplacement() {
    return this.replacement != null;
  }
  
  /**
   * Method is deprecated. use withReplacement instead.
   */
  @java.lang.Deprecated
  public A withNewReplacement(java.lang.String arg0) {
    return (A)withReplacement(new String(arg0));
  }
  public java.lang.String getSeparator() {
    return this.separator;
  }
  public A withSeparator(java.lang.String separator) {
    this.separator=separator; return (A) this;
  }
  public java.lang.Boolean hasSeparator() {
    return this.separator != null;
  }
  
  /**
   * Method is deprecated. use withSeparator instead.
   */
  @java.lang.Deprecated
  public A withNewSeparator(java.lang.String arg0) {
    return (A)withSeparator(new String(arg0));
  }
  public A addToSourceLabels(java.lang.Integer index,java.lang.String item) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    this.sourceLabels.add(index, item);
    return (A)this;
  }
  public A setToSourceLabels(java.lang.Integer index,java.lang.String item) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    this.sourceLabels.set(index, item); return (A)this;
  }
  public A addToSourceLabels(java.lang.String... items) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sourceLabels.add(item);} return (A)this;
  }
  public A addAllToSourceLabels(java.util.Collection<java.lang.String> items) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sourceLabels.add(item);} return (A)this;
  }
  public A removeFromSourceLabels(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.sourceLabels!= null){ this.sourceLabels.remove(item);}} return (A)this;
  }
  public A removeAllFromSourceLabels(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.sourceLabels!= null){ this.sourceLabels.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSourceLabels() {
    return this.sourceLabels;
  }
  public java.lang.String getSourceLabel(java.lang.Integer index) {
    return this.sourceLabels.get(index);
  }
  public java.lang.String getFirstSourceLabel() {
    return this.sourceLabels.get(0);
  }
  public java.lang.String getLastSourceLabel() {
    return this.sourceLabels.get(sourceLabels.size() - 1);
  }
  public java.lang.String getMatchingSourceLabel(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sourceLabels) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSourceLabel(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sourceLabels) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSourceLabels(java.util.List<java.lang.String> sourceLabels) {
    if (sourceLabels != null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : sourceLabels){this.addToSourceLabels(item);}} else { this.sourceLabels = null;} return (A) this;
  }
  public A withSourceLabels(java.lang.String... sourceLabels) {
    if (this.sourceLabels != null) {this.sourceLabels.clear();}
    if (sourceLabels != null) {for (java.lang.String item :sourceLabels){ this.addToSourceLabels(item);}} return (A) this;
  }
  public java.lang.Boolean hasSourceLabels() {
    return sourceLabels != null && !sourceLabels.isEmpty();
  }
  public A addNewSourceLabel(java.lang.String arg0) {
    return (A)addToSourceLabels(new String(arg0));
  }
  public java.lang.String getTargetLabel() {
    return this.targetLabel;
  }
  public A withTargetLabel(java.lang.String targetLabel) {
    this.targetLabel=targetLabel; return (A) this;
  }
  public java.lang.Boolean hasTargetLabel() {
    return this.targetLabel != null;
  }
  
  /**
   * Method is deprecated. use withTargetLabel instead.
   */
  @java.lang.Deprecated
  public A withNewTargetLabel(java.lang.String arg0) {
    return (A)withTargetLabel(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RelabelConfigFluentImpl that = (RelabelConfigFluentImpl) o;
    if (action != null ? !action.equals(that.action) :that.action != null) return false;
    if (modulus != null ? !modulus.equals(that.modulus) :that.modulus != null) return false;
    if (regex != null ? !regex.equals(that.regex) :that.regex != null) return false;
    if (replacement != null ? !replacement.equals(that.replacement) :that.replacement != null) return false;
    if (separator != null ? !separator.equals(that.separator) :that.separator != null) return false;
    if (sourceLabels != null ? !sourceLabels.equals(that.sourceLabels) :that.sourceLabels != null) return false;
    if (targetLabel != null ? !targetLabel.equals(that.targetLabel) :that.targetLabel != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(action,  modulus,  regex,  replacement,  separator,  sourceLabels,  targetLabel,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RelabelConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RelabelConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.RelabelConfigFluent<A>{
  public RelabelConfigFluentImpl() {
  }
  public RelabelConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.RelabelConfig instance) {
    this.withAction(instance.getAction()); 
    this.withModulus(instance.getModulus()); 
    this.withRegex(instance.getRegex()); 
    this.withReplacement(instance.getReplacement()); 
    this.withSeparator(instance.getSeparator()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withTargetLabel(instance.getTargetLabel()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String action;
  private java.lang.Long modulus;
  private java.lang.String regex;
  private java.lang.String replacement;
  private java.lang.String separator;
  private java.util.List<java.lang.String> sourceLabels = new java.util.ArrayList<java.lang.String>();
  private java.lang.String targetLabel;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getAction() {
    return this.action;
  }
  public A withAction(java.lang.String action) {
    this.action=action; return (A) this;
  }
  public java.lang.Boolean hasAction() {
    return this.action != null;
  }
  
  /**
   * Method is deprecated. use withAction instead.
   */
  @java.lang.Deprecated
  public A withNewAction(java.lang.String arg0) {
    return (A)withAction(new String(arg0));
  }
  public java.lang.Long getModulus() {
    return this.modulus;
  }
  public A withModulus(java.lang.Long modulus) {
    this.modulus=modulus; return (A) this;
  }
  public java.lang.Boolean hasModulus() {
    return this.modulus != null;
  }
  public java.lang.String getRegex() {
    return this.regex;
  }
  public A withRegex(java.lang.String regex) {
    this.regex=regex; return (A) this;
  }
  public java.lang.Boolean hasRegex() {
    return this.regex != null;
  }
  
  /**
   * Method is deprecated. use withRegex instead.
   */
  @java.lang.Deprecated
  public A withNewRegex(java.lang.String arg0) {
    return (A)withRegex(new String(arg0));
  }
  public java.lang.String getReplacement() {
    return this.replacement;
  }
  public A withReplacement(java.lang.String replacement) {
    this.replacement=replacement; return (A) this;
  }
  public java.lang.Boolean hasReplacement() {
    return this.replacement != null;
  }
  
  /**
   * Method is deprecated. use withReplacement instead.
   */
  @java.lang.Deprecated
  public A withNewReplacement(java.lang.String arg0) {
    return (A)withReplacement(new String(arg0));
  }
  public java.lang.String getSeparator() {
    return this.separator;
  }
  public A withSeparator(java.lang.String separator) {
    this.separator=separator; return (A) this;
  }
  public java.lang.Boolean hasSeparator() {
    return this.separator != null;
  }
  
  /**
   * Method is deprecated. use withSeparator instead.
   */
  @java.lang.Deprecated
  public A withNewSeparator(java.lang.String arg0) {
    return (A)withSeparator(new String(arg0));
  }
  public A addToSourceLabels(java.lang.Integer index,java.lang.String item) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    this.sourceLabels.add(index, item);
    return (A)this;
  }
  public A setToSourceLabels(java.lang.Integer index,java.lang.String item) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    this.sourceLabels.set(index, item); return (A)this;
  }
  public A addToSourceLabels(java.lang.String... items) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sourceLabels.add(item);} return (A)this;
  }
  public A addAllToSourceLabels(java.util.Collection<java.lang.String> items) {
    if (this.sourceLabels == null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.sourceLabels.add(item);} return (A)this;
  }
  public A removeFromSourceLabels(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.sourceLabels!= null){ this.sourceLabels.remove(item);}} return (A)this;
  }
  public A removeAllFromSourceLabels(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.sourceLabels!= null){ this.sourceLabels.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSourceLabels() {
    return this.sourceLabels;
  }
  public java.lang.String getSourceLabel(java.lang.Integer index) {
    return this.sourceLabels.get(index);
  }
  public java.lang.String getFirstSourceLabel() {
    return this.sourceLabels.get(0);
  }
  public java.lang.String getLastSourceLabel() {
    return this.sourceLabels.get(sourceLabels.size() - 1);
  }
  public java.lang.String getMatchingSourceLabel(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sourceLabels) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSourceLabel(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: sourceLabels) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSourceLabels(java.util.List<java.lang.String> sourceLabels) {
    if (sourceLabels != null) {this.sourceLabels = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : sourceLabels){this.addToSourceLabels(item);}} else { this.sourceLabels = null;} return (A) this;
  }
  public A withSourceLabels(java.lang.String... sourceLabels) {
    if (this.sourceLabels != null) {this.sourceLabels.clear();}
    if (sourceLabels != null) {for (java.lang.String item :sourceLabels){ this.addToSourceLabels(item);}} return (A) this;
  }
  public java.lang.Boolean hasSourceLabels() {
    return sourceLabels != null && !sourceLabels.isEmpty();
  }
  public A addNewSourceLabel(java.lang.String arg0) {
    return (A)addToSourceLabels(new String(arg0));
  }
  public java.lang.String getTargetLabel() {
    return this.targetLabel;
  }
  public A withTargetLabel(java.lang.String targetLabel) {
    this.targetLabel=targetLabel; return (A) this;
  }
  public java.lang.Boolean hasTargetLabel() {
    return this.targetLabel != null;
  }
  
  /**
   * Method is deprecated. use withTargetLabel instead.
   */
  @java.lang.Deprecated
  public A withNewTargetLabel(java.lang.String arg0) {
    return (A)withTargetLabel(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RelabelConfigFluentImpl that = (RelabelConfigFluentImpl) o;
    if (action != null ? !action.equals(that.action) :that.action != null) return false;
    if (modulus != null ? !modulus.equals(that.modulus) :that.modulus != null) return false;
    if (regex != null ? !regex.equals(that.regex) :that.regex != null) return false;
    if (replacement != null ? !replacement.equals(that.replacement) :that.replacement != null) return false;
    if (separator != null ? !separator.equals(that.separator) :that.separator != null) return false;
    if (sourceLabels != null ? !sourceLabels.equals(that.sourceLabels) :that.sourceLabels != null) return false;
    if (targetLabel != null ? !targetLabel.equals(that.targetLabel) :that.targetLabel != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(action,  modulus,  regex,  replacement,  separator,  sourceLabels,  targetLabel,  additionalProperties,  super.hashCode());
  }
  
}
